@@ -688,6 +688,7 @@ class Sf:
         
         return result_dict
     
+    ## TODO: This function can be made much more efficient by doing all of the object, permission, and profile metadata retrievals in one go
     async def field_permission_user_bulk_check(self, objects: list, permissions: list,  users= [], ):
         data = {}
         task_dict = {}
@@ -893,7 +894,7 @@ class Sf:
         for object in object_list:
             permissionable_fields[object] = task_result_dict[object]['fields'].T[task_result_dict[object]['fields'].T['permissionable'] == True].index.tolist()
             nonpermissionable_fields[object] = task_result_dict[object]['fields'].T[task_result_dict[object]['fields'].T['permissionable'] == False].index.tolist()
-        return permissionable_fields, nonpermissionable_fields
+        return permissionable_fields, nonpermissionable_fields, task_result_dict
     
     ### ----------------------------------------------------------------------------------------------------
     ### Synchronous Metadata Functions
@@ -1176,7 +1177,7 @@ class Sf:
         profiles = ['Admin' if x == 'System Administrator' else x for x in profiles]
 
 
-        async_metadata_read = async_wrap(sf.metadata_read)
+        async_metadata_read = async_wrap(self.metadata_read)
         profile_metadata_tasks = {}
         profile_metadata_dict = {}
 
